From: normalperson@... Date: 2015-01-17T03:17:28+00:00 Subject: [ruby-core:67646] [ruby-trunk - Bug #10723] [PERF] bm_tread_create_join 20% slower Issue #10723 has been updated by Eric Wong. Minor micro-optimization, I could not find much improvement while keeping functionality: http://80x24.org/spew/m/thread-microopt-v1%40r49282.txt target 0: 2.1.5 (ruby 2.1.5p273 (2014-11-13 revision 48405) [x86_64-linux]) at "/home/ew/ruby-2.1/bin/ruby" target 1: trunk (ruby 2.3.0dev (2015-01-16 trunk 49282) [x86_64-linux]) at "/home/ew/rrrr/b/i/bin/ruby" target 2: built (ruby 2.3.0dev (2015-01-16 trunk 49282) [x86_64-linux]) at "/home/ew/ruby/b/i/bin/ruby" 2.1.5 1.0573025540215895 2.1.5 1.0493981029139832 2.1.5 1.0576379200210795 trunk 1.2876477020327002 trunk 1.2424484699731693 trunk 1.2432217099703848 built 1.1531978889834136 built 1.137529328931123 built 1.1509092160267755 Elapsed time: 10.381246521 (sec) ----------------------------------------------------------- benchmark results: minimum results in each 3 measurements. Execution time (sec) name 2.1.5 trunk built vm_thread_create_join 1.049 1.242 1.138 Speedup ratio: compare with the result of `2.1.5' (greater is better) name trunk built vm_thread_create_join 0.845 0.923 ---------------------------------------- Bug #10723: [PERF] bm_tread_create_join 20% slower https://bugs.ruby-lang.org/issues/10723#change-51066 * Author: Guo Xiang Tan * Status: Open * Priority: Normal * Assignee: * ruby -v: ruby 2.2.0dev (2014-09-21 trunk 47676) * Backport: 2.0.0: UNKNOWN, 2.1: UNKNOWN, 2.2: UNKNOWN ---------------------------------------- Relevant commits: https://github.com/ruby/ruby/compare/39fd4a8...5697b2f Chart showing the regression: http://rubybench.org/ruby/ruby/commits?result_type=vm_thread_create_join For those unable to view the chart, the benchmark results have increased from 1.74~ seconds to 2.1~ seconds. -- https://bugs.ruby-lang.org/